% BOXPLOT: Function plots a box
%
%          function boxplot(box,c)
%
%          box: matrix containing 8 columnvectors which specify
%               the edges in clock or anticlockwise order for the
%               bottom 4 and top 4 and such that the bottom 4
%               allign with the top 4.
%          c  : color and edge/surface string (optional)
%               examples 'r' (red edges) 'gs' (green surface)
%               default 'r'
%
%          Example: plot a cube
%
%          figure(gcf); clf; r1=1; l=2*r1;
%          axis([-l l -l l -l l]); hold on;
%          e1=[-r1;  r1; r1; 1]; e2=[-r1; -r1; r1; 1];
%          e3=[-r1; -r1;-r1; 1]; e4=[-r1;  r1;-r1; 1]; % bottom 4
%          e5=[ r1;  r1; r1; 1]; e6=[ r1; -r1; r1; 1];
%          e7=[ r1; -r1;-r1; 1]; e8=[ r1;  r1;-r1; 1]; % top 4
%          boxplot([e1 e2 e3 e4 e5 e6 e7 e8]); hold off; figure(gcf);
%
%          L.G. van Willigenburg 23-5-'96
%
  function boxplot(box,c)

  [n,m]=size(box);
  if n~=4 | m~=8; error('The first input argument should be a 4x8 matrix'); end;

  if nargin<2; c='r'; end;
  if isempty(c); c='r'; end;

  [nc,mc]=size(c); if mc>1; c=c(1); end;

% If color edge/surface switch is not a string
  if ~isstr(c)
    if c<0.33; c='r';
    elseif c<0.66; c='g';
    else c='b'; end;
  end;

  if mc<2;
% Plot edges
    k=box(:,[1:4 1]); plot3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[5:8 5]); plot3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[1 5]); plot3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[2 6]); plot3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[3 7]); plot3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[4 8]); plot3(k(1,:),k(2,:),k(3,:),c);
  else
% Plot surfaces
    k=box(:,[1:4 1]); fill3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[5:8 5]); fill3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[1 2 6 5]); fill3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[4 3 7 8]); fill3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[4 1 5 8]); fill3(k(1,:),k(2,:),k(3,:),c);
    k=box(:,[2 3 7 6]); fill3(k(1,:),k(2,:),k(3,:),c);
  end
